#ifndef BOOST_SIMD_INCLUDE_FUNCTIONS_FIRSTBITUNSET_HPP_INCLUDED
#define BOOST_SIMD_INCLUDE_FUNCTIONS_FIRSTBITUNSET_HPP_INCLUDED

#include <boost/simd/bitwise/include/functions/firstbitunset.hpp>

#endif
